@@ -17,12 +17,25 @@ namespace AndroidPositioning
 
     QGeoPositionInfoSource::Error startUpdates(int androidClassKey);
     void stopUpdates(int androidClassKey);
-    QGeoPositionInfoSource::Error requestUpdate(int androidClassKey);
+    QGeoPositionInfoSource::Error requestUpdate(int androidClassKey, int timeout);
 
     QGeoSatelliteInfoSource::Error startSatelliteUpdates(int androidClassKey,
                                                          bool isSingleRequest,
                                                          int updateRequestTimeout);
-    bool requestionPositioningPermissions();
+
+    // This basically mimics QGeoPositionInfoSource::PositioningMethods,
+    // but we introduce a separate enum, because it's also used when accessing
+    // QGeoSatelliteInfoSouce.
+    enum class AccuracyType : quint8
+    {
+        None = 0x00,
+        Precise = 0x01,
+        Approximate = 0x02,
+        Any = 0xFF,
+    };
+    Q_DECLARE_FLAGS(AccuracyTypes, AccuracyType)
+
+    bool hasPositioningPermissions(AccuracyTypes accuracy);
 }
 
 #endif // JNIPOSITIONING_H
